Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CiPipelineLogTemplate ¶ added in v0.46.0
type CiPipelineLogTemplate string
type CiReporter ¶ added in v0.46.0
type CiReporter struct {
// contains filtered or unexported fields
}
func NewCiReporterForAzureDevOps ¶ added in v0.46.0
func NewCiReporterForAzureDevOps() CiReporter
func NewCiReporterForGithubActions ¶ added in v0.46.0
func NewCiReporterForGithubActions() CiReporter
func NewCiReporterForGitlab ¶ added in v0.46.0
func NewCiReporterForGitlab() CiReporter
func NewCiReporterFromEnv ¶ added in v0.46.0
func NewCiReporterFromEnv() CiReporter
func NewCiReporterWithGenericFormat ¶ added in v0.46.0
func NewCiReporterWithGenericFormat() CiReporter
type JSONReporter ¶ added in v0.22.0
type JSONReporter struct{}
JSONReporter prints failures as a single JSON struct, allowing for simple machine-readable output.
The format is:
{
"lints":
[
{"filename": FILENAME, "line": LINE, "column": COL, "message": MESSAGE, "rule": RULE}
],
}
type JUnitFailure ¶ added in v0.15.0
type JUnitFailure struct {
Message string `xml:"message,attr"`
Type string `xml:"type,attr"`
Contents string `xml:",cdata"`
}
JUnitFailure contains data related to a failed test.
type JUnitReporter ¶ added in v0.15.0
type JUnitReporter struct{}
JUnitReporter prints failures in JUnit XML format.
type JUnitTestCase ¶ added in v0.15.0
type JUnitTestCase struct {
XMLName xml.Name `xml:"testcase"`
ClassName string `xml:"classname,attr"`
Name string `xml:"name,attr"`
Time string `xml:"time,attr"`
Failure *JUnitFailure `xml:"failure,omitempty"`
}
JUnitTestCase is a single test case with its result.
type JUnitTestSuite ¶ added in v0.15.0
type JUnitTestSuite struct {
XMLName xml.Name `xml:"testsuite"`
Package string `xml:"package"`
Tests int `xml:"tests,attr"`
Failures int `xml:"failures,attr"`
Time string `xml:"time,attr"`
TestCases []JUnitTestCase
}
JUnitTestSuite is a single JUnit test suite which may contain many testcases.
type JUnitTestSuites ¶ added in v0.15.0
type JUnitTestSuites struct {
XMLName xml.Name `xml:"testsuites"`
Suites []JUnitTestSuite
}
JUnitTestSuites is a collection of JUnit test suites.
type MCPReporter ¶ added in v0.55.0
type MCPReporter struct{}
MCPReporter prints failures in MCP friendly JSON format.
type SarifReporter ¶ added in v0.44.0
type SarifReporter struct{}
SarifReporter creates reports formatted as a JSON Document. The document format is used according to the SARIF Standard. Refer to http://docs.oasis-open.org/sarif/sarif/v2.1.0/sarif-v2.1.0.html for details to the format.
type SonarReporter ¶ added in v0.46.0
type SonarReporter struct {
}
type TscReporter ¶ added in v0.47.0
type TscReporter struct{}
TscRport prints failures as string compatible to Type script compiler
The format is "FILENAME(LINE,COL): SEVERITY RULE_ID: MESSAGE".
type UnixReporter ¶ added in v0.21.0
type UnixReporter struct{}
UnixReporter prints failures as it respects Unix output conventions those are frequently employed by preprocessors and compilers.
The format is "FILENAME:LINE:COL: MESSAGE".