Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JSONReporter ¶ added in v0.22.0
type JSONReporter struct{}
JSONReporter prints failures as a single JSON struct, allowing for simple machine-readable output.
The format is:
{
"lints":
[
{"filename": FILENAME, "line": LINE, "column": COL, "message": MESSAGE, "rule": RULE}
],
}
type JUnitFailure ¶ added in v0.15.0
type JUnitFailure struct {
Message string `xml:"message,attr"`
Type string `xml:"type,attr"`
Contents string `xml:",cdata"`
}
JUnitFailure contains data related to a failed test.
type JUnitReporter ¶ added in v0.15.0
type JUnitReporter struct{}
JUnitReporter prints failures in JUnit XML format.
type JUnitTestCase ¶ added in v0.15.0
type JUnitTestCase struct {
XMLName xml.Name `xml:"testcase"`
ClassName string `xml:"classname,attr"`
Name string `xml:"name,attr"`
Time string `xml:"time,attr"`
Failure *JUnitFailure `xml:"failure,omitempty"`
}
JUnitTestCase is a single test case with its result.
type JUnitTestSuite ¶ added in v0.15.0
type JUnitTestSuite struct {
XMLName xml.Name `xml:"testsuite"`
Package string `xml:"package"`
Tests int `xml:"tests,attr"`
Failures int `xml:"failures,attr"`
Time string `xml:"time,attr"`
TestCases []JUnitTestCase
}
JUnitTestSuite is a single JUnit test suite which may contain many testcases.
type JUnitTestSuites ¶ added in v0.15.0
type JUnitTestSuites struct {
XMLName xml.Name `xml:"testsuites"`
Suites []JUnitTestSuite
}
JUnitTestSuites is a collection of JUnit test suites.
type UnixReporter ¶ added in v0.21.0
type UnixReporter struct{}
UnixReporter prints failures as it respects Unix output conventions those are frequently employed by preprocessors and compilers.
The format is "FILENAME:LINE:COL: MESSAGE".
Click to show internal directories.
Click to hide internal directories.